==> home-made-io-fastmag-sync-m2-0.25.0-3b5902.zip: Setup/Patch/Data/InstallCustomerAddressAttributes.php <==
<?php
/*******************************************************************************
 * Created by HOMEMADE.IO SAS.
 * Fastmag Sync  -  Connect Fastmag with your Magento
 *
 * Copyright (C) HOMEMADE.IO SAS, Inc - All Rights Reserved
 *
 * @author    Simon Laubet-Xavier <simon.laubetxavier@home-made.io>
 * @copyright 2020-2021 HOMEMADE.IO SAS
 * @date      2021-07-27
 ******************************************************************************/

namespace Fastmag\Sync\Setup\Patch\Data;

use Fastmag\Sync\Model\Constants;
use Magento\Customer\Api\AddressMetadataInterface;
use Magento\Customer\Setup\CustomerSetupFactory;
use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\Setup\ModuleDataSetupInterface;
use Magento\Framework\Setup\Patch\DataPatchInterface;
use Magento\Framework\Setup\Patch\PatchRevertableInterface;
use Zend_Validate_Exception;

/**
 * Class InstallCustomerAddressAttributes
 *
 * Installer for customer address attributes
 */
class InstallCustomerAddressAttributes implements DataPatchInterface, PatchRevertableInterface
{
    /** @var ModuleDataSetupInterface */
    protected $moduleDataSetup;

    /** @var CustomerSetupFactory $customerSetupFactory */
    protected $customerSetupFactory;

    /**
     * InstallCustomerAddressAttributes constructor
     *
     * @param ModuleDataSetupInterface $moduleDataSetup
     * @param CustomerSetupFactory     $customerSetupFactory
     */
    public function __construct(ModuleDataSetupInterface $moduleDataSetup, CustomerSetupFactory $customerSetupFactory)
    {
        $this->moduleDataSetup = $moduleDataSetup;
        $this->customerSetupFactory = $customerSetupFactory;
    }

    /**
     * @inheritdoc
     */
    public static function getDependencies()
    {
        return [];
    }

    /**
     * @inheritdoc
     */
    public function getAliases()
    {
        return [];
    }

    /**
     * @inheritDoc
     *
     * @throws LocalizedException
     * @throws Zend_Validate_Exception
     */
    public function apply()
    {
        $customerSetup = $this->customerSetupFactory->create(['setup' => $this->moduleDataSetup]);
        $customerSetup->addAttribute(
            AddressMetadataInterface::ENTITY_TYPE_ADDRESS,
            Constants::ATTRIBUTE_ADDRESS_ALIAS_CODE,
            [
                'label'    => 'Fastmag Alias',
                'required' => false,
                'position' => 100,
                'system'   => false,
                'default'  => Constants::ATTRIBUTE_ADDRESS_ALIAS_DEFAULT
            ]
        );
    }

    /**
     * @inheritDoc
     */
    public function revert()
    {
        $customerSetup = $this->customerSetupFactory->create(['setup' => $this->moduleDataSetup]);
        $customerSetup->removeAttribute(
            AddressMetadataInterface::ENTITY_TYPE_ADDRESS,
            Constants::ATTRIBUTE_ADDRESS_ALIAS_CODE
        );
    }
}

==> home-made-io-fastmag-sync-m2-1.7.3-729356.zip: Setup/Patch/Data/InstallCustomerAddressAttributes.php <==
<?php
/*******************************************************************************
 * Created by HOMEMADE.IO SAS.
 * Fastmag Sync  -  Connect Fastmag with your Magento
 *
 * Copyright (C) HOMEMADE.IO SAS, Inc - All Rights Reserved
 *
 * @author    Simon Laubet-Xavier <simon.laubetxavier@home-made.io>
 * @copyright 2020-2023 HOMEMADE.IO SAS
 * @date      2023-05-10
 ******************************************************************************/

namespace Fastmag\Sync\Setup\Patch\Data;

use Fastmag\Sync\Model\Constants;
use Magento\Customer\Api\AddressMetadataInterface as AddressMetadata;
use Magento\Customer\Setup\CustomerSetupFactory;
use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\Setup\ModuleDataSetupInterface as ModuleDataSetup;
use Magento\Framework\Setup\Patch\DataPatchInterface;
use Magento\Framework\Setup\Patch\PatchRevertableInterface;
use Magento\Framework\Validator\ValidateException;

/**
 * Class InstallCustomerAddressAttributes
 *
 * Installer for customer address attributes
 */
class InstallCustomerAddressAttributes implements DataPatchInterface, PatchRevertableInterface
{
    /** @var ModuleDataSetup $moduleDataSetup */
    protected ModuleDataSetup $moduleDataSetup;

    /** @var CustomerSetupFactory $customerSetupFactory */
    protected CustomerSetupFactory $customerSetupFactory;

    /**
     * InstallCustomerAddressAttributes constructor
     *
     * @param ModuleDataSetup      $moduleDataSetup
     * @param CustomerSetupFactory $customerSetupFactory
     */
    public function __construct(ModuleDataSetup $moduleDataSetup, CustomerSetupFactory $customerSetupFactory)
    {
        $this->moduleDataSetup = $moduleDataSetup;
        $this->customerSetupFactory = $customerSetupFactory;
    }

    /**
     * @inheritdoc
     */
    public static function getDependencies(): array
    {
        return [];
    }

    /**
     * @inheritdoc
     */
    public function getAliases(): array
    {
        return [];
    }

    /**
     * @inheritDoc
     *
     * @throws LocalizedException
     * @throws ValidateException
     */
    public function apply()
    {
        $customerSetup = $this->customerSetupFactory->create(['setup' => $this->moduleDataSetup]);
        $customerSetup->addAttribute(
            AddressMetadata::ENTITY_TYPE_ADDRESS,
            Constants::ATTRIBUTE_ADDRESS_ALIAS_CODE,
            [
                'label'    => 'Fastmag Alias',
                'required' => false,
                'position' => 1001,
                'system'   => false,
                'visible'  => false
            ]
        );
    }

    /**
     * @inheritDoc
     */
    public function revert()
    {
        $customerSetup = $this->customerSetupFactory->create(['setup' => $this->moduleDataSetup]);
        $customerSetup->removeAttribute(
            AddressMetadata::ENTITY_TYPE_ADDRESS,
            Constants::ATTRIBUTE_ADDRESS_ALIAS_CODE
        );
    }
}
